==> cloudfoundry-client-2.4.0.BUILD-20170216.155240-40-sources.jar: org/cloudfoundry/client/v2/spaces/_ListSpaceServicesRequest.java <==
/*
 * Copyright 2013-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.spaces;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.cloudfoundry.Nullable;
import org.cloudfoundry.client.v2.InFilterParameter;
import org.cloudfoundry.client.v2.PaginatedRequest;
import org.immutables.value.Value;

import java.util.List;

/**
 * The request payload for the List all Services for the Space operation
 */
@Value.Immutable
abstract class _ListSpaceServicesRequest extends PaginatedRequest {

    /**
     * The actives
     */
    @InFilterParameter("active")
    @Nullable
    abstract List<String> getActives();

    /**
     * The labels
     */
    @InFilterParameter("label")
    @Nullable
    abstract List<String> getLabels();

    /**
     * The providers
     */
    @InFilterParameter("provider")
    @Nullable
    abstract List<String> getProviders();

    /**
     * The service broker ids
     */
    @InFilterParameter("service_broker_guid")
    @Nullable
    abstract List<String> getServiceBrokerIds();

    /**
     * The space id
     */
    @JsonIgnore
    abstract String getSpaceId();

}

==> cloudfoundry-client-2.22.0.BUILD-20171107.200356-8-sources.jar: org/cloudfoundry/client/v2/spaces/_ListSpaceServicesRequest.java <==
/*
 * Copyright 2013-2017 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.cloudfoundry.client.v2.spaces;

import com.fasterxml.jackson.annotation.JsonIgnore;
import org.cloudfoundry.Nullable;
import org.cloudfoundry.client.v2.FilterParameter;
import org.cloudfoundry.client.v2.PaginatedRequest;
import org.immutables.value.Value;

import java.util.List;

/**
 * The request payload for the List all Services for the Space operation
 */
@Value.Immutable
abstract class _ListSpaceServicesRequest extends PaginatedRequest {

    /**
     * The actives
     */
    @FilterParameter("active")
    @Nullable
    abstract List<String> getActives();

    /**
     * The labels
     */
    @FilterParameter("label")
    @Nullable
    abstract List<String> getLabels();

    /**
     * The providers
     */
    @FilterParameter("provider")
    @Nullable
    abstract List<String> getProviders();

    /**
     * The service broker ids
     */
    @FilterParameter("service_broker_guid")
    @Nullable
    abstract List<String> getServiceBrokerIds();

    /**
     * The space id
     */
    @JsonIgnore
    abstract String getSpaceId();

}
